@@ -9,7 +9,7 @@ This file contains typedefs related to state vector types.
 #ifndef STATE_VECTOR_TYPES_H
 #define STATE_VECTOR_TYPES_H
 
-#include "orbit_math_types.h"
+#include "vec_math_types.h"
 
 typedef struct StateVector
 {
